from setuptools import setup
 
setup(name='mmxtest',
  version='1.0.3',
  description='A print test for PyPI',
  author='mmx',
  author_email='mingxing157157@163.com',
  url='https://www.python.org/',
  license='MIT',
  keywords='ga nn',
  project_urls={
   'Documentation': 'https://packaging.python.org/tutorials/distributing-packages/',
   'Funding': 'https://donate.pypi.org',
   'Source': 'https://github.com/pypa/sampleproject/',
   'Tracker': 'https://github.com/pypa/sampleproject/issues',
  },
  )
